@@ -2,7 +2,7 @@ import importlib
 import json
 from .Service import initService, BaseService, LoginService, OAuth2Service
 from .User import initUser
-from .Token import initToken
+from .Token import initToken, Token
 from typing import Union
 import os
 import requests
@@ -11,6 +11,31 @@ import logging
 logger = logging.getLogger()
 
 
+def parseUserId(obj: str):
+    service, user = obj.split("://")
+    userId, password = user.split(":")
+    service = service.replace("port-", "")
+
+    if password == "None":
+        password = None
+
+    if userId == "":
+        userId = None
+
+    if password == "":
+        password = None
+
+    return service, userId, password
+
+
+def parseToken(token: Token):
+    serviceport = "port-{}".format(token.service.servicename)
+    data = {
+        "userId": "{}://{}:{}".format(serviceport, token.user.username, token.access_token)}
+
+    return data
+
+
 def getServiceObject(obj: Union[str, dict]):
     """Creates a service object, corresponding to the given object
 
@@ -245,7 +270,8 @@ def try_function_on_dict(func: list):
                 continue
 
         raise Exception(
-            "The given jsonDict raise in all functions an exception: \n{}".format(
+            "The given jsonDict raise in all functions an exception.\ndata: {}, errors: \n{}".format(
+                jsonDict,
                 "\n".join(
                     [f"Error: {type(e)}, Msg: {str(e)}" for e in exp_list])
             )
